# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["PercentageShare"]


class PercentageShare(BaseModel):
    exact: Optional[float] = None
    """The exact share of this interest held (if available)."""

    exclusive_maximum: Optional[float] = FieldInfo(alias="exclusiveMaximum", default=None)
    """The exclusive upper bound of the share of this interest."""

    exclusive_minimum: Optional[float] = FieldInfo(alias="exclusiveMinimum", default=None)
    """The exclusive lower bound of the share of this interest."""

    maximum: Optional[float] = None
    """The inclusive upper bound of the share of this interest."""

    minimum: Optional[float] = None
    """The inclusive lower bound of the share of this interest."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .person import Person
from .._models import BaseModel
from .date_info import DateInfo
from .interest_type import InterestType
from .percentage_share import PercentageShare

__all__ = ["UltimateBeneficialOwner", "Interest"]


class Interest(BaseModel):
    details: Optional[str] = None

    end_date: Optional[DateInfo] = FieldInfo(alias="endDate", default=None)

    percentage: Optional[PercentageShare] = None
    """
    The proportion of this type of interest held by the interested party, where an
    interest is countable.
    """

    start_date: Optional[DateInfo] = FieldInfo(alias="startDate", default=None)

    type: Optional[InterestType] = None
    """
    Describes the nature of the interest or control that an entity or person has in
    another entity.
    """


class UltimateBeneficialOwner(BaseModel):
    interests: Optional[List[Interest]] = None
    """
    The local name given to this kind of interest, or further information
    (semi-structured or unstructured) to clarify the nature of the interest.
    """

    person: Optional[Person] = None
    """A natural person (human being)"""

    source: Optional[str] = None

    type: Optional[Literal["person"]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Optional
from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["SecretUpdateParams"]


class SecretUpdateParams(TypedDict, total=False):
    secret_values: Required[Annotated[Dict[str, str], PropertyInfo(alias="secretValues")]]

    partner_customer_id: Annotated[Optional[str], PropertyInfo(alias="partnerCustomerId")]
    """Partner customer ID"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List

from pydantic import Field as FieldInfo

from ..._models import BaseModel
from .company_search_result import CompanySearchResult

__all__ = ["SearchIndexResponse", "Pagination"]


class Pagination(BaseModel):
    has_more: bool = FieldInfo(alias="hasMore")

    limit: int

    page: int


class SearchIndexResponse(BaseModel):
    pagination: Pagination
    """Pagination information for search results."""

    search_results: List[CompanySearchResult] = FieldInfo(alias="searchResults")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Optional

from ..._models import BaseModel

__all__ = ["Identifier"]


class Identifier(BaseModel):
    type: str
    """The type must include the jurisdiction in which it is issued"""

    value: str
    """The text/number value of the identifier"""

    description: Optional[str] = None
    """
    Free-text description of the identifier when type is unknown or needs
    clarification
    """

    extra: Optional[Dict[str, object]] = None
    """Additional metadata about the identifier"""

    source: Optional[str] = None
    """The source of this identifier (e.g., 'registrar', 'company', 'third_party')"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Union
from datetime import datetime
from typing_extensions import TypeAlias

from pydantic import Field as FieldInfo

from .. import product_order_response
from ..._models import BaseModel
from .document_result import DocumentResult

__all__ = ["ProductOrderResponse", "DownloadDocumentResponse"]


class DownloadDocumentResponse(BaseModel):
    content_type: str = FieldInfo(alias="contentType")
    """MIME type of the document"""

    download_link: str = FieldInfo(alias="downloadLink")
    """URL for downloading the document"""

    expires_at: datetime = FieldInfo(alias="expiresAt")
    """Timestamp when the download URL expires"""

    file_name: str = FieldInfo(alias="fileName")
    """Suggested filename for the download"""

    kausate_document_id: str = FieldInfo(alias="kausateDocumentId")
    """Kausate document ID"""


ProductOrderResponse: TypeAlias = Union[
    product_order_response.ProductOrderResponse, DocumentResult, DownloadDocumentResponse
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Union, Optional
from datetime import datetime
from typing_extensions import TypeAlias

from pydantic import Field as FieldInfo

from ..._models import BaseModel
from ..product_order_response import ProductOrderResponse

__all__ = ["DocumentListResponse", "ListDocumentsResponse", "ListDocumentsResponseDocument"]


class ListDocumentsResponseDocument(BaseModel):
    kausate_document_id: str = FieldInfo(alias="kausateDocumentId")
    """Stable document ID for download requests"""

    title: str
    """Full title of the document"""

    document_type: Optional[str] = FieldInfo(alias="documentType", default=None)
    """Document type (annualAccounts, currentExtract, shareholderList, etc.)"""

    file_type: Optional[str] = FieldInfo(alias="fileType", default=None)
    """File format/extension (pdf, xml, etc.)"""

    publication_date: Optional[str] = FieldInfo(alias="publicationDate", default=None)
    """Date when the document was published (ISO format)"""

    publication_type: Optional[str] = FieldInfo(alias="publicationType", default=None)
    """Publication type name from the source register"""

    source: Optional[str] = None
    """Source register of the document"""


class ListDocumentsResponse(BaseModel):
    documents: List[ListDocumentsResponseDocument]
    """List of available documents"""

    kausate_id: str = FieldInfo(alias="kausateId")
    """Kausate company identifier"""

    total_count: int = FieldInfo(alias="totalCount")
    """Total number of documents found"""

    expires_at: Optional[datetime] = FieldInfo(alias="expiresAt", default=None)
    """Timestamp when the index expires"""

    indexed_at: Optional[datetime] = FieldInfo(alias="indexedAt", default=None)
    """Timestamp when the documents were indexed"""


DocumentListResponse: TypeAlias = Union[ProductOrderResponse, ListDocumentsResponse]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["DocumentResult"]


class DocumentResult(BaseModel):
    content_type: Optional[str] = FieldInfo(alias="contentType", default=None)

    document_type: Optional[str] = FieldInfo(alias="documentType", default=None)

    download_link: Optional[str] = FieldInfo(alias="downloadLink", default=None)

    expires_at: Optional[str] = FieldInfo(alias="expiresAt", default=None)

    file_name: Optional[str] = FieldInfo(alias="fileName", default=None)

    kausate_document_id: Optional[str] = FieldInfo(alias="kausateDocumentId", default=None)

    type: Optional[Literal["document"]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["DocumentListParams"]


class DocumentListParams(TypedDict, total=False):
    sync: bool
    """Return result synchronously (default: true)"""

    customer_reference: Annotated[Optional[str], PropertyInfo(alias="customerReference")]

    x_partner_customer_id: Annotated[str, PropertyInfo(alias="X-Partner-Customer-Id")]
    """Optional partner customer ID"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel
from .company_search_result import CompanySearchResult

__all__ = ["LiveSearchResponse"]


class LiveSearchResponse(BaseModel):
    search_results: List[CompanySearchResult] = FieldInfo(alias="searchResults")

    type: Optional[Literal["liveSearch"]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Optional
from typing_extensions import Annotated, TypeAlias, TypedDict

from ..._utils import PropertyInfo
from .uk_advanced_query_param import UkAdvancedQueryParam
from .german_advanced_query_param import GermanAdvancedQueryParam

__all__ = ["SearchIndexParams", "AdvancedQuery"]


class SearchIndexParams(TypedDict, total=False):
    advanced_query: Annotated[Optional[AdvancedQuery], PropertyInfo(alias="advancedQuery")]
    """Jurisdiction-specific advanced search query.

    The structure varies based on the 'jurisdiction' field.
    """

    include_alternative_names: Annotated[bool, PropertyInfo(alias="includeAlternativeNames")]
    """If true, searches alternative company names (more expensive).

    Default: false for optimal performance.
    """

    include_similar_names: Annotated[bool, PropertyInfo(alias="includeSimilarNames")]
    """
    If true, falls back to trigram similarity search when no exact matches found
    (more expensive). Default: false for optimal performance.
    """

    jurisdiction_code: Annotated[str, PropertyInfo(alias="jurisdictionCode")]
    """
    ISO 3166-1 alpha-2 country code (e.g., 'de' for Germany, 'uk' for United
    Kingdom)
    """

    limit: Optional[int]

    name: Optional[str]
    """Company name to search for. Either 'name' or 'advancedQuery' must be provided."""

    page: Optional[int]
    """Page number (0-based)"""

    x_partner_customer_id: Annotated[str, PropertyInfo(alias="X-Partner-Customer-Id")]
    """Optional partner customer ID"""


AdvancedQuery: TypeAlias = Union[GermanAdvancedQueryParam, UkAdvancedQueryParam]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from kausate import Kausate, AsyncKausate
from tests.utils import assert_matches_type
from kausate.types.companies import (
    SearchIndexResponse,
    SearchRealTimeResponse,
    SearchAutocompleteResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestSearch:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_autocomplete(self, client: Kausate) -> None:
        search = client.companies.search.autocomplete(
            query="xx",
        )
        assert_matches_type(SearchAutocompleteResponse, search, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_autocomplete_with_all_params(self, client: Kausate) -> None:
        search = client.companies.search.autocomplete(
            query="xx",
            jurisdiction_code="jurisdictionCode",
            limit=1,
        )
        assert_matches_type(SearchAutocompleteResponse, search, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_autocomplete(self, client: Kausate) -> None:
        response = client.companies.search.with_raw_response.autocomplete(
            query="xx",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        search = response.parse()
        assert_matches_type(SearchAutocompleteResponse, search, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_autocomplete(self, client: Kausate) -> None:
        with client.companies.search.with_streaming_response.autocomplete(
            query="xx",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            search = response.parse()
            assert_matches_type(SearchAutocompleteResponse, search, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_index(self, client: Kausate) -> None:
        search = client.companies.search.index()
        assert_matches_type(SearchIndexResponse, search, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_index_with_all_params(self, client: Kausate) -> None:
        search = client.companies.search.index(
            advanced_query={
                "court_city": "München",
                "court_id": "D2803",
                "jurisdiction": "de",
                "name": "BMW AG",
                "register_number": "10364B",
                "register_suffix": "B",
                "register_type": "HRB",
            },
            include_alternative_names=True,
            include_similar_names=True,
            jurisdiction_code="jurisdictionCode",
            limit=1,
            name="x",
            page=0,
            x_partner_customer_id="X-Partner-Customer-Id",
        )
        assert_matches_type(SearchIndexResponse, search, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_index(self, client: Kausate) -> None:
        response = client.companies.search.with_raw_response.index()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        search = response.parse()
        assert_matches_type(SearchIndexResponse, search, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_index(self, client: Kausate) -> None:
        with client.companies.search.with_streaming_response.index() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            search = response.parse()
            assert_matches_type(SearchIndexResponse, search, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_real_time(self, client: Kausate) -> None:
        search = client.companies.search.real_time()
        assert_matches_type(SearchRealTimeResponse, search, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_real_time_with_all_params(self, client: Kausate) -> None:
        search = client.companies.search.real_time(
            sync=True,
            advanced_query={
                "court_city": "München",
                "court_id": "D2803",
                "jurisdiction": "de",
                "name": "BMW AG",
                "register_number": "10364B",
                "register_suffix": "B",
                "register_type": "HRB",
            },
            company_name="x",
            customer_reference="customerReference",
            jurisdiction_code="jurisdictionCode",
            x_partner_customer_id="X-Partner-Customer-Id",
        )
        assert_matches_type(SearchRealTimeResponse, search, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_real_time(self, client: Kausate) -> None:
        response = client.companies.search.with_raw_response.real_time()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        search = response.parse()
        assert_matches_type(SearchRealTimeResponse, search, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_real_time(self, client: Kausate) -> None:
        with client.companies.search.with_streaming_response.real_time() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            search = response.parse()
            assert_matches_type(SearchRealTimeResponse, search, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncSearch:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_autocomplete(self, async_client: AsyncKausate) -> None:
        search = await async_client.companies.search.autocomplete(
            query="xx",
        )
        assert_matches_type(SearchAutocompleteResponse, search, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_autocomplete_with_all_params(self, async_client: AsyncKausate) -> None:
        search = await async_client.companies.search.autocomplete(
            query="xx",
            jurisdiction_code="jurisdictionCode",
            limit=1,
        )
        assert_matches_type(SearchAutocompleteResponse, search, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_autocomplete(self, async_client: AsyncKausate) -> None:
        response = await async_client.companies.search.with_raw_response.autocomplete(
            query="xx",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        search = await response.parse()
        assert_matches_type(SearchAutocompleteResponse, search, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_autocomplete(self, async_client: AsyncKausate) -> None:
        async with async_client.companies.search.with_streaming_response.autocomplete(
            query="xx",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            search = await response.parse()
            assert_matches_type(SearchAutocompleteResponse, search, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_index(self, async_client: AsyncKausate) -> None:
        search = await async_client.companies.search.index()
        assert_matches_type(SearchIndexResponse, search, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_index_with_all_params(self, async_client: AsyncKausate) -> None:
        search = await async_client.companies.search.index(
            advanced_query={
                "court_city": "München",
                "court_id": "D2803",
                "jurisdiction": "de",
                "name": "BMW AG",
                "register_number": "10364B",
                "register_suffix": "B",
                "register_type": "HRB",
            },
            include_alternative_names=True,
            include_similar_names=True,
            jurisdiction_code="jurisdictionCode",
            limit=1,
            name="x",
            page=0,
            x_partner_customer_id="X-Partner-Customer-Id",
        )
        assert_matches_type(SearchIndexResponse, search, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_index(self, async_client: AsyncKausate) -> None:
        response = await async_client.companies.search.with_raw_response.index()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        search = await response.parse()
        assert_matches_type(SearchIndexResponse, search, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_index(self, async_client: AsyncKausate) -> None:
        async with async_client.companies.search.with_streaming_response.index() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            search = await response.parse()
            assert_matches_type(SearchIndexResponse, search, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_real_time(self, async_client: AsyncKausate) -> None:
        search = await async_client.companies.search.real_time()
        assert_matches_type(SearchRealTimeResponse, search, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_real_time_with_all_params(self, async_client: AsyncKausate) -> None:
        search = await async_client.companies.search.real_time(
            sync=True,
            advanced_query={
                "court_city": "München",
                "court_id": "D2803",
                "jurisdiction": "de",
                "name": "BMW AG",
                "register_number": "10364B",
                "register_suffix": "B",
                "register_type": "HRB",
            },
            company_name="x",
            customer_reference="customerReference",
            jurisdiction_code="jurisdictionCode",
            x_partner_customer_id="X-Partner-Customer-Id",
        )
        assert_matches_type(SearchRealTimeResponse, search, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_real_time(self, async_client: AsyncKausate) -> None:
        response = await async_client.companies.search.with_raw_response.real_time()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        search = await response.parse()
        assert_matches_type(SearchRealTimeResponse, search, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_real_time(self, async_client: AsyncKausate) -> None:
        async with async_client.companies.search.with_streaming_response.real_time() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            search = await response.parse()
            assert_matches_type(SearchRealTimeResponse, search, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["SecretDeleteParams"]


class SecretDeleteParams(TypedDict, total=False):
    partner_customer_id: Annotated[Optional[str], PropertyInfo(alias="partnerCustomerId")]
    """Partner customer ID"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["InterestType"]

InterestType: TypeAlias = Literal[
    "shareholding",
    "votingRights",
    "appointmentOfBoard",
    "otherInfluenceOrControl",
    "seniorManagingOfficial",
    "settlor",
    "trustee",
    "protector",
    "beneficiaryOfLegalArrangement",
    "rightsToSurplusAssetsOnDissolution",
    "rightsToProfitOrIncome",
    "rightsGrantedByContract",
    "conditionalRightsGrantedByContract",
    "controlViaCompanyRulesOrArticles",
    "controlByLegalFramework",
    "boardMember",
    "boardChair",
    "unknownInterest",
    "unpublishedInterest",
    "enjoymentAndUseOfAssets",
    "rightToProfitOrIncomeFromAssets",
    "nominee",
    "nominator",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Any, Optional, cast
from typing_extensions import Literal

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, strip_not_given, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.companies import product_order_params
from ...types.companies.product_order_response import ProductOrderResponse

__all__ = ["ProductsResource", "AsyncProductsResource"]


class ProductsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ProductsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/kausate/sdk-python#accessing-raw-response-data-eg-headers
        """
        return ProductsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ProductsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/kausate/sdk-python#with_streaming_response
        """
        return ProductsResourceWithStreamingResponse(self)

    def order(
        self,
        kausate_id: str,
        *,
        sync: bool | Omit = omit,
        customer_reference: Optional[str] | Omit = omit,
        kausate_document_id: Optional[str] | Omit = omit,
        output_format: Literal["pdf", "raw"] | Omit = omit,
        sku: Optional[str] | Omit = omit,
        x_partner_customer_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ProductOrderResponse:
        """Order a real-time product (e.g.

        company document) for a company (asynchronous or
        synchronous processing).

        Typical workflow:

        1. Use `GET /v2/companies/search/indexed?name=...&jurisdictionCode=...` to find
           the company and get its `kausateId`.
        2. Call this endpoint `POST /v2/companies/{kausateId}/products/order` with the
           document type.
        3. If sync=false (default): Use the returned `orderId` to poll
           `GET /v2/orders/{orderId}` for the result.
        4. If sync=true: The response will contain the document data directly (300s
           timeout).

        Examples of currently supported SKUs for Germany (DE):

        - `DEHRAD` (Current Register Information)
        - `DEHRSL` (Shareholders List)
        - `DEHRCD` (Chronological Register Information)
        - `DEHRAA` (Articles of Association)
        - `DEHRSI` (Structured Information)
        - `DEHRMP` (Model Protocol)

        - **kausateId**: Company ID to order product for
        - **sku**: Product SKU code
        - **customerReference**: Optional reference for tracking
        - **sync**: Return result synchronously with 300s timeout (default: false)

        Returns order ID for tracking (async) or document data (sync).

        Args:
          kausate_id: Company ID

          sync: Return result synchronously with 300s timeout

          kausate_document_id: Document ID from /documents/list response (e.g., doc_deur_abc123). Required if
              sku not provided.

          output_format: Output format. 'pdf' converts TIFF files to PDF (default). 'raw' keeps original
              format.

          sku: Product SKU code (e.g., DEHRAD, DEHRSI). Required if kausateDocumentId not
              provided.

          x_partner_customer_id: Optional partner customer ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not kausate_id:
            raise ValueError(f"Expected a non-empty value for `kausate_id` but received {kausate_id!r}")
        extra_headers = {**strip_not_given({"X-Partner-Customer-Id": x_partner_customer_id}), **(extra_headers or {})}
        return cast(
            ProductOrderResponse,
            self._post(
                f"/v2/companies/{kausate_id}/products/order",
                body=maybe_transform(
                    {
                        "customer_reference": customer_reference,
                        "kausate_document_id": kausate_document_id,
                        "output_format": output_format,
                        "sku": sku,
                    },
                    product_order_params.ProductOrderParams,
                ),
                options=make_request_options(
                    extra_headers=extra_headers,
                    extra_query=extra_query,
                    extra_body=extra_body,
                    timeout=timeout,
                    query=maybe_transform({"sync": sync}, product_order_params.ProductOrderParams),
                ),
                cast_to=cast(
                    Any, ProductOrderResponse
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )


class AsyncProductsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncProductsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/kausate/sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncProductsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncProductsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/kausate/sdk-python#with_streaming_response
        """
        return AsyncProductsResourceWithStreamingResponse(self)

    async def order(
        self,
        kausate_id: str,
        *,
        sync: bool | Omit = omit,
        customer_reference: Optional[str] | Omit = omit,
        kausate_document_id: Optional[str] | Omit = omit,
        output_format: Literal["pdf", "raw"] | Omit = omit,
        sku: Optional[str] | Omit = omit,
        x_partner_customer_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ProductOrderResponse:
        """Order a real-time product (e.g.

        company document) for a company (asynchronous or
        synchronous processing).

        Typical workflow:

        1. Use `GET /v2/companies/search/indexed?name=...&jurisdictionCode=...` to find
           the company and get its `kausateId`.
        2. Call this endpoint `POST /v2/companies/{kausateId}/products/order` with the
           document type.
        3. If sync=false (default): Use the returned `orderId` to poll
           `GET /v2/orders/{orderId}` for the result.
        4. If sync=true: The response will contain the document data directly (300s
           timeout).

        Examples of currently supported SKUs for Germany (DE):

        - `DEHRAD` (Current Register Information)
        - `DEHRSL` (Shareholders List)
        - `DEHRCD` (Chronological Register Information)
        - `DEHRAA` (Articles of Association)
        - `DEHRSI` (Structured Information)
        - `DEHRMP` (Model Protocol)

        - **kausateId**: Company ID to order product for
        - **sku**: Product SKU code
        - **customerReference**: Optional reference for tracking
        - **sync**: Return result synchronously with 300s timeout (default: false)

        Returns order ID for tracking (async) or document data (sync).

        Args:
          kausate_id: Company ID

          sync: Return result synchronously with 300s timeout

          kausate_document_id: Document ID from /documents/list response (e.g., doc_deur_abc123). Required if
              sku not provided.

          output_format: Output format. 'pdf' converts TIFF files to PDF (default). 'raw' keeps original
              format.

          sku: Product SKU code (e.g., DEHRAD, DEHRSI). Required if kausateDocumentId not
              provided.

          x_partner_customer_id: Optional partner customer ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not kausate_id:
            raise ValueError(f"Expected a non-empty value for `kausate_id` but received {kausate_id!r}")
        extra_headers = {**strip_not_given({"X-Partner-Customer-Id": x_partner_customer_id}), **(extra_headers or {})}
        return cast(
            ProductOrderResponse,
            await self._post(
                f"/v2/companies/{kausate_id}/products/order",
                body=await async_maybe_transform(
                    {
                        "customer_reference": customer_reference,
                        "kausate_document_id": kausate_document_id,
                        "output_format": output_format,
                        "sku": sku,
                    },
                    product_order_params.ProductOrderParams,
                ),
                options=make_request_options(
                    extra_headers=extra_headers,
                    extra_query=extra_query,
                    extra_body=extra_body,
                    timeout=timeout,
                    query=await async_maybe_transform({"sync": sync}, product_order_params.ProductOrderParams),
                ),
                cast_to=cast(
                    Any, ProductOrderResponse
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )


class ProductsResourceWithRawResponse:
    def __init__(self, products: ProductsResource) -> None:
        self._products = products

        self.order = to_raw_response_wrapper(
            products.order,
        )


class AsyncProductsResourceWithRawResponse:
    def __init__(self, products: AsyncProductsResource) -> None:
        self._products = products

        self.order = async_to_raw_response_wrapper(
            products.order,
        )


class ProductsResourceWithStreamingResponse:
    def __init__(self, products: ProductsResource) -> None:
        self._products = products

        self.order = to_streamed_response_wrapper(
            products.order,
        )


class AsyncProductsResourceWithStreamingResponse:
    def __init__(self, products: AsyncProductsResource) -> None:
        self._products = products

        self.order = async_to_streamed_response_wrapper(
            products.order,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .address import Address as Address
from .identifier import Identifier as Identifier
from .document_result import DocumentResult as DocumentResult
from .search_index_params import SearchIndexParams as SearchIndexParams
from .document_list_params import DocumentListParams as DocumentListParams
from .live_search_response import LiveSearchResponse as LiveSearchResponse
from .product_order_params import ProductOrderParams as ProductOrderParams
from .report_create_params import ReportCreateParams as ReportCreateParams
from .company_search_result import CompanySearchResult as CompanySearchResult
from .search_index_response import SearchIndexResponse as SearchIndexResponse
from .document_list_response import DocumentListResponse as DocumentListResponse
from .product_order_response import ProductOrderResponse as ProductOrderResponse
from .report_create_response import ReportCreateResponse as ReportCreateResponse
from .search_real_time_params import SearchRealTimeParams as SearchRealTimeParams
from .uk_advanced_query_param import UkAdvancedQueryParam as UkAdvancedQueryParam
from .search_real_time_response import SearchRealTimeResponse as SearchRealTimeResponse
from .search_autocomplete_params import SearchAutocompleteParams as SearchAutocompleteParams
from .german_advanced_query_param import GermanAdvancedQueryParam as GermanAdvancedQueryParam
from .search_autocomplete_response import SearchAutocompleteResponse as SearchAutocompleteResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .orders import (
    OrdersResource,
    AsyncOrdersResource,
    OrdersResourceWithRawResponse,
    AsyncOrdersResourceWithRawResponse,
    OrdersResourceWithStreamingResponse,
    AsyncOrdersResourceWithStreamingResponse,
)
from .secrets import (
    SecretsResource,
    AsyncSecretsResource,
    SecretsResourceWithRawResponse,
    AsyncSecretsResourceWithRawResponse,
    SecretsResourceWithStreamingResponse,
    AsyncSecretsResourceWithStreamingResponse,
)
from .webhooks import (
    WebhooksResource,
    AsyncWebhooksResource,
    WebhooksResourceWithRawResponse,
    AsyncWebhooksResourceWithRawResponse,
    WebhooksResourceWithStreamingResponse,
    AsyncWebhooksResourceWithStreamingResponse,
)
from .companies import (
    CompaniesResource,
    AsyncCompaniesResource,
    CompaniesResourceWithRawResponse,
    AsyncCompaniesResourceWithRawResponse,
    CompaniesResourceWithStreamingResponse,
    AsyncCompaniesResourceWithStreamingResponse,
)

__all__ = [
    "CompaniesResource",
    "AsyncCompaniesResource",
    "CompaniesResourceWithRawResponse",
    "AsyncCompaniesResourceWithRawResponse",
    "CompaniesResourceWithStreamingResponse",
    "AsyncCompaniesResourceWithStreamingResponse",
    "OrdersResource",
    "AsyncOrdersResource",
    "OrdersResourceWithRawResponse",
    "AsyncOrdersResourceWithRawResponse",
    "OrdersResourceWithStreamingResponse",
    "AsyncOrdersResourceWithStreamingResponse",
    "SecretsResource",
    "AsyncSecretsResource",
    "SecretsResourceWithRawResponse",
    "AsyncSecretsResourceWithRawResponse",
    "SecretsResourceWithStreamingResponse",
    "AsyncSecretsResourceWithStreamingResponse",
    "WebhooksResource",
    "AsyncWebhooksResource",
    "WebhooksResourceWithRawResponse",
    "AsyncWebhooksResourceWithRawResponse",
    "WebhooksResourceWithStreamingResponse",
    "AsyncWebhooksResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Optional
from typing_extensions import Literal, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["GermanAdvancedQueryParam"]


class GermanAdvancedQueryParam(TypedDict, total=False):
    court_city: Annotated[Optional[str], PropertyInfo(alias="courtCity")]
    """Court city name (e.g., 'München', 'Berlin').

    Will be fuzzy-matched and converted to courtId. Cannot be used with courtId.
    Empty string treated as None.
    """

    court_id: Annotated[Optional[str], PropertyInfo(alias="courtId")]
    """Court ID (e.g., 'D2803', 'D2601').

    Cannot be used with courtCity. Empty string treated as None.
    """

    jurisdiction: Literal["de"]
    """
    Jurisdiction discriminator (automatically inferred from jurisdictionCode at API
    level)
    """

    name: Optional[str]
    """Company name to search for.

    Can be used alone or combined with identifier fields for more specific searches.
    Empty string treated as None.
    """

    register_number: Annotated[Union[str, int, None], PropertyInfo(alias="registerNumber")]
    """Register number (e.g., '10364B', '10364', 10364, 'HRB 275800', or 'HR B
    275800').

    Can include register type prefix (HRB, HRA, HR B, HR A, G NR, etc.) which will
    be automatically extracted and used if registerType is not explicitly provided.
    Supports both spaced (HR B) and non-spaced (HRB) variants. If string contains
    suffix, it will be extracted.
    """

    register_suffix: Annotated[Optional[str], PropertyInfo(alias="registerSuffix")]
    """Register suffix (e.g., 'B', 'BHV').

    Can be provided explicitly or extracted from registerNumber. Case-insensitive -
    will be normalized to uppercase. Empty string treated as None.
    """

    register_type: Annotated[Optional[str], PropertyInfo(alias="registerType")]
    """Register type (e.g., 'HRB', 'HRA', 'GNR', 'PR', 'VR').

    Case-insensitive - will be normalized to uppercase. Empty string treated as
    None.
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Union, Optional
from typing_extensions import Annotated, TypeAlias, TypedDict

from ..._utils import PropertyInfo
from .uk_advanced_query_param import UkAdvancedQueryParam
from .german_advanced_query_param import GermanAdvancedQueryParam

__all__ = ["SearchRealTimeParams", "AdvancedQuery"]


class SearchRealTimeParams(TypedDict, total=False):
    sync: bool
    """If True, wait for results. If False, return workflow ID immediately"""

    advanced_query: Annotated[Optional[AdvancedQuery], PropertyInfo(alias="advancedQuery")]
    """Jurisdiction-specific advanced search query.

    The structure varies based on the 'jurisdiction' field.
    """

    company_name: Annotated[Optional[str], PropertyInfo(alias="companyName")]
    """Company name to search for.

    Either 'companyName' or 'advancedQuery' must be provided.
    """

    customer_reference: Annotated[Optional[str], PropertyInfo(alias="customerReference")]
    """Optional customer reference for tracking"""

    jurisdiction_code: Annotated[str, PropertyInfo(alias="jurisdictionCode")]
    """
    ISO 3166-1 alpha-2 country code (e.g., 'de' for Germany, 'uk' for United
    Kingdom)
    """

    x_partner_customer_id: Annotated[str, PropertyInfo(alias="X-Partner-Customer-Id")]
    """Optional partner customer ID"""


AdvancedQuery: TypeAlias = Union[GermanAdvancedQueryParam, UkAdvancedQueryParam]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["UkAdvancedQueryParam"]


class UkAdvancedQueryParam(TypedDict, total=False):
    company_number: Required[Annotated[str, PropertyInfo(alias="companyNumber")]]
    """Companies House company number (e.g., '09410276')"""

    jurisdiction: Literal["uk"]
    """
    Jurisdiction discriminator (automatically inferred from jurisdictionCode at API
    level)
    """



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Optional
from typing_extensions import TypedDict

from .webhook_status import WebhookStatus

__all__ = ["WebhookUpdateParams"]


class WebhookUpdateParams(TypedDict, total=False):
    api_version: Optional[str]
    """API version for the webhook"""

    custom_headers: Optional[Dict[str, str]]
    """Custom request headers to include in webhook requests"""

    description: Optional[str]
    """Optional description"""

    name: Optional[str]
    """Name of the webhook"""

    partner_customer_id: Optional[str]
    """Optional partner customer ID"""

    status: Optional[WebhookStatus]
    """Status of a webhook configuration."""

    url: Optional[str]
    """URL to receive webhook notifications"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal

import httpx

from ..types import order_list_params, order_retrieve_params
from .._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.order_list_response import OrderListResponse
from ..types.order_retrieve_response import OrderRetrieveResponse

__all__ = ["OrdersResource", "AsyncOrdersResource"]


class OrdersResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> OrdersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/kausate/sdk-python#accessing-raw-response-data-eg-headers
        """
        return OrdersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> OrdersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/kausate/sdk-python#with_streaming_response
        """
        return OrdersResourceWithStreamingResponse(self)

    def retrieve(
        self,
        order_id: str,
        *,
        customer_partner_id: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderRetrieveResponse:
        """
        Retrieve detailed information about a specific order.

        Args:
          order_id: Order ID to retrieve details for

          customer_partner_id: Optional customer partner ID for validation

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not order_id:
            raise ValueError(f"Expected a non-empty value for `order_id` but received {order_id!r}")
        return self._get(
            f"/v2/orders/{order_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {"customer_partner_id": customer_partner_id}, order_retrieve_params.OrderRetrieveParams
                ),
            ),
            cast_to=OrderRetrieveResponse,
        )

    def list(
        self,
        *,
        limit: int | Omit = omit,
        workflow_type: Optional[Literal["DocumentRetrieval", "CompanyReport", "ShareholderGraph", "UBOExtraction"]]
        | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderListResponse:
        """
        Retrieve a list of orders for your organization.

        Args:
          limit: Maximum number of orders to return

          workflow_type: Available workflow types for filtering orders.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/v2/orders",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "limit": limit,
                        "workflow_type": workflow_type,
                    },
                    order_list_params.OrderListParams,
                ),
            ),
            cast_to=OrderListResponse,
        )


class AsyncOrdersResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncOrdersResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/kausate/sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncOrdersResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncOrdersResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/kausate/sdk-python#with_streaming_response
        """
        return AsyncOrdersResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        order_id: str,
        *,
        customer_partner_id: Optional[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderRetrieveResponse:
        """
        Retrieve detailed information about a specific order.

        Args:
          order_id: Order ID to retrieve details for

          customer_partner_id: Optional customer partner ID for validation

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not order_id:
            raise ValueError(f"Expected a non-empty value for `order_id` but received {order_id!r}")
        return await self._get(
            f"/v2/orders/{order_id}",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"customer_partner_id": customer_partner_id}, order_retrieve_params.OrderRetrieveParams
                ),
            ),
            cast_to=OrderRetrieveResponse,
        )

    async def list(
        self,
        *,
        limit: int | Omit = omit,
        workflow_type: Optional[Literal["DocumentRetrieval", "CompanyReport", "ShareholderGraph", "UBOExtraction"]]
        | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OrderListResponse:
        """
        Retrieve a list of orders for your organization.

        Args:
          limit: Maximum number of orders to return

          workflow_type: Available workflow types for filtering orders.

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/v2/orders",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "limit": limit,
                        "workflow_type": workflow_type,
                    },
                    order_list_params.OrderListParams,
                ),
            ),
            cast_to=OrderListResponse,
        )


class OrdersResourceWithRawResponse:
    def __init__(self, orders: OrdersResource) -> None:
        self._orders = orders

        self.retrieve = to_raw_response_wrapper(
            orders.retrieve,
        )
        self.list = to_raw_response_wrapper(
            orders.list,
        )


class AsyncOrdersResourceWithRawResponse:
    def __init__(self, orders: AsyncOrdersResource) -> None:
        self._orders = orders

        self.retrieve = async_to_raw_response_wrapper(
            orders.retrieve,
        )
        self.list = async_to_raw_response_wrapper(
            orders.list,
        )


class OrdersResourceWithStreamingResponse:
    def __init__(self, orders: OrdersResource) -> None:
        self._orders = orders

        self.retrieve = to_streamed_response_wrapper(
            orders.retrieve,
        )
        self.list = to_streamed_response_wrapper(
            orders.list,
        )


class AsyncOrdersResourceWithStreamingResponse:
    def __init__(self, orders: AsyncOrdersResource) -> None:
        self._orders = orders

        self.retrieve = async_to_streamed_response_wrapper(
            orders.retrieve,
        )
        self.list = async_to_streamed_response_wrapper(
            orders.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, Optional
from datetime import datetime

from .._models import BaseModel
from .webhook_status import WebhookStatus

__all__ = ["WebhookResponse"]


class WebhookResponse(BaseModel):
    id: str
    """Webhook ID"""

    api_version: str
    """API version for the webhook"""

    created_at: datetime
    """Creation timestamp"""

    name: str
    """Name of the webhook"""

    org_id: str
    """Organization ID"""

    status: WebhookStatus
    """Webhook status"""

    updated_at: datetime
    """Last update timestamp"""

    url: str
    """URL to receive webhook notifications"""

    custom_headers: Optional[Dict[str, str]] = None
    """Custom request headers (including Authorization) to include in webhook requests"""

    description: Optional[str] = None
    """Optional description"""

    partner_customer_id: Optional[str] = None
    """Optional partner customer ID"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Union
from typing_extensions import TypeAlias

from .live_search_response import LiveSearchResponse
from ..product_order_response import ProductOrderResponse

__all__ = ["SearchRealTimeResponse"]

SearchRealTimeResponse: TypeAlias = Union[LiveSearchResponse, ProductOrderResponse]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["ProductOrderParams"]


class ProductOrderParams(TypedDict, total=False):
    sync: bool
    """Return result synchronously with 300s timeout"""

    customer_reference: Annotated[Optional[str], PropertyInfo(alias="customerReference")]

    kausate_document_id: Annotated[Optional[str], PropertyInfo(alias="kausateDocumentId")]
    """Document ID from /documents/list response (e.g., doc_deur_abc123).

    Required if sku not provided.
    """

    output_format: Annotated[Literal["pdf", "raw"], PropertyInfo(alias="outputFormat")]
    """Output format.

    'pdf' converts TIFF files to PDF (default). 'raw' keeps original format.
    """

    sku: Optional[str]
    """Product SKU code (e.g., DEHRAD, DEHRSI).

    Required if kausateDocumentId not provided.
    """

    x_partner_customer_id: Annotated[str, PropertyInfo(alias="X-Partner-Customer-Id")]
    """Optional partner customer ID"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from .._models import BaseModel

__all__ = ["DateInfo"]


class DateInfo(BaseModel):
    normalized: Optional[str] = None

    original: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Union, Optional
from datetime import datetime
from typing_extensions import Literal, Annotated, TypeAlias

from pydantic import Field as FieldInfo

from .._utils import PropertyInfo
from .._models import BaseModel
from .currency import Currency
from .date_info import DateInfo
from .interest_type import InterestType
from .company_report import CompanyReport
from .percentage_share import PercentageShare
from .companies.address import Address
from .companies.identifier import Identifier
from .shareholder_report_data import ShareholderReportData
from .companies.document_result import DocumentResult
from .companies.live_search_response import LiveSearchResponse
from .ultimate_beneficial_owner_report import UltimateBeneficialOwnerReport

__all__ = [
    "OrderRetrieveResponse",
    "Result",
    "ResultShareholderReport",
    "ResultShareholderGraphResult",
    "ResultShareholderGraphResultGraph",
    "ResultShareholderGraphResultGraphEdge",
    "ResultShareholderGraphResultGraphEdgeData",
    "ResultShareholderGraphResultGraphNode",
    "ResultShareholderGraphResultGraphNodeData",
    "ResultShareholderGraphResultGraphNodeDataCompanyNodeData",
    "ResultShareholderGraphResultGraphNodeDataPersonNodeData",
    "ResultShareholderGraphResultGraphNodeDataFreeFloatNodeData",
]


class ResultShareholderReport(BaseModel):
    shareholder_report: ShareholderReportData = FieldInfo(alias="shareholderReport")

    type: Optional[Literal["shareholderReport"]] = None


class ResultShareholderGraphResultGraphEdgeData(BaseModel):
    interest_details: Optional[str] = FieldInfo(alias="interestDetails", default=None)
    """
    Additional details about the interest, such as the specific role name (e.g.,
    'Komplementär', 'Managing Director')
    """

    interest_type: Optional[InterestType] = FieldInfo(alias="interestType", default=None)
    """
    Describes the nature of the interest or control that an entity or person has in
    another entity.
    """

    number_of_shares: Optional[int] = FieldInfo(alias="numberOfShares", default=None)

    percentage: Optional[PercentageShare] = None
    """
    The proportion of this type of interest held by the interested party, where an
    interest is countable.
    """

    share_class: Optional[str] = FieldInfo(alias="shareClass", default=None)

    total_nominal_value: Optional[Currency] = FieldInfo(alias="totalNominalValue", default=None)
    """Total nominal value with amount and ISO 4217 currency code"""


class ResultShareholderGraphResultGraphEdge(BaseModel):
    id: str
    """Unique identifier for the edge"""

    source: str
    """ID of the source node (owner)"""

    target: str
    """ID of the target node (owned)"""

    data: Optional[ResultShareholderGraphResultGraphEdgeData] = None
    """Data for an edge in the shareholder graph."""


class ResultShareholderGraphResultGraphNodeDataCompanyNodeData(BaseModel):
    kausate_id: str = FieldInfo(alias="kausateId")

    legal_name: str = FieldInfo(alias="legalName")

    cumulative_ownership: Optional[PercentageShare] = FieldInfo(alias="cumulativeOwnership", default=None)
    """
    The proportion of this type of interest held by the interested party, where an
    interest is countable.
    """

    has_more_shareholders: Optional[bool] = FieldInfo(alias="hasMoreShareholders", default=None)

    identifiers: Optional[List[Identifier]] = None
    """
    List of identifiers found for this company (e.g., registration numbers, tax IDs)
    """

    is_expanded: Optional[bool] = FieldInfo(alias="isExpanded", default=None)

    jurisdiction_code: Optional[str] = FieldInfo(alias="jurisdictionCode", default=None)

    shareholder_count: Optional[int] = FieldInfo(alias="shareholderCount", default=None)

    shareholder_report: Optional[ShareholderReportData] = FieldInfo(alias="shareholderReport", default=None)
    """Full shareholder report data if extracted"""


class ResultShareholderGraphResultGraphNodeDataPersonNodeData(BaseModel):
    name: str

    address: Optional[Address] = None
    """Address of a company or person."""

    contact: Optional[Dict[str, str]] = None

    cumulative_ownership: Optional[PercentageShare] = FieldInfo(alias="cumulativeOwnership", default=None)
    """
    The proportion of this type of interest held by the interested party, where an
    interest is countable.
    """

    date_of_birth: Optional[DateInfo] = FieldInfo(alias="dateOfBirth", default=None)

    gender: Optional[str] = None

    identifiers: Optional[List[Identifier]] = None

    jurisdiction_code: Optional[str] = FieldInfo(alias="jurisdictionCode", default=None)

    nationality: Optional[str] = None

    role: Optional[str] = None


class ResultShareholderGraphResultGraphNodeDataFreeFloatNodeData(BaseModel):
    cumulative_ownership: Optional[PercentageShare] = FieldInfo(alias="cumulativeOwnership", default=None)
    """
    The proportion of this type of interest held by the interested party, where an
    interest is countable.
    """

    description: Optional[str] = None
    """Description of the free float"""

    name: Optional[str] = None
    """Display name for the free float"""


ResultShareholderGraphResultGraphNodeData: TypeAlias = Union[
    ResultShareholderGraphResultGraphNodeDataCompanyNodeData,
    ResultShareholderGraphResultGraphNodeDataPersonNodeData,
    ResultShareholderGraphResultGraphNodeDataFreeFloatNodeData,
]


class ResultShareholderGraphResultGraphNode(BaseModel):
    id: str
    """Unique identifier for the node"""

    data: ResultShareholderGraphResultGraphNodeData
    """Node-specific data"""

    type: Literal["company", "person", "rootEntity", "freeFloat"]
    """Type of node"""


class ResultShareholderGraphResultGraph(BaseModel):
    edges: Optional[List[ResultShareholderGraphResultGraphEdge]] = None

    extraction_timestamp: Optional[str] = FieldInfo(alias="extractionTimestamp", default=None)

    max_depth: Optional[int] = FieldInfo(alias="maxDepth", default=None)

    nodes: Optional[List[ResultShareholderGraphResultGraphNode]] = None

    root_company_id: Optional[str] = FieldInfo(alias="rootCompanyId", default=None)


class ResultShareholderGraphResult(BaseModel):
    graph: ResultShareholderGraphResultGraph
    """Graph structure with nodes and edges"""

    type: Optional[Literal["shareholderGraph"]] = None


Result: TypeAlias = Annotated[
    Union[
        DocumentResult,
        CompanyReport,
        ResultShareholderReport,
        ResultShareholderGraphResult,
        UltimateBeneficialOwnerReport,
        LiveSearchResponse,
        None,
    ],
    PropertyInfo(discriminator="type"),
]


class OrderRetrieveResponse(BaseModel):
    order_id: str = FieldInfo(alias="orderId")
    """Order ID (temporal workflow id)"""

    request_time: datetime = FieldInfo(alias="requestTime")

    status: Literal["running", "completed", "failed", "canceled", "terminated", "timedOut"]
    """Order status"""

    current_activity: Optional[str] = FieldInfo(alias="currentActivity", default=None)
    """Currently running activity name"""

    customer_reference: Optional[str] = FieldInfo(alias="customerReference", default=None)
    """Customer reference"""

    error: Optional[str] = None
    """Error message if the order failed"""

    partner_customer_id: Optional[str] = FieldInfo(alias="partnerCustomerId", default=None)
    """Partner customer ID"""

    response_time: Optional[datetime] = FieldInfo(alias="responseTime", default=None)

    result: Optional[Result] = None
    """Document download result."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .address import Address
from ..._models import BaseModel
from .identifier import Identifier

__all__ = ["CompanySearchResult"]


class CompanySearchResult(BaseModel):
    jurisdiction_code: str = FieldInfo(alias="jurisdictionCode")
    """ISO 3166-1 alpha-2 country code"""

    kausate_id: str = FieldInfo(alias="kausateId")

    name: str

    addresses: Optional[List[Address]] = None
    """Company addresses (registered office, business addresses, etc.)"""

    alternative_names: Optional[List[str]] = FieldInfo(alias="alternativeNames", default=None)
    """All alternative names (former names) for this company from the index"""

    identifiers: Optional[List[Identifier]] = None
    """Company identifiers (e.g., HR number for German companies)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["LegalForm"]


class LegalForm(BaseModel):
    iso20275_legal_form_code: Optional[str] = FieldInfo(alias="iso20275LegalFormCode", default=None)

    normalized: Optional[str] = None

    original: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .role import Role as Role
from .person import Person as Person
from .status import Status as Status
from .currency import Currency as Currency
from .date_info import DateInfo as DateInfo
from .legal_form import LegalForm as LegalForm
from .shareholder import Shareholder as Shareholder
from .interest_type import InterestType as InterestType
from .company_report import CompanyReport as CompanyReport
from .webhook_status import WebhookStatus as WebhookStatus
from .signatory_rules import SignatoryRules as SignatoryRules
from .percentage_share import PercentageShare as PercentageShare
from .webhook_response import WebhookResponse as WebhookResponse
from .order_list_params import OrderListParams as OrderListParams
from .secret_list_params import SecretListParams as SecretListParams
from .order_list_response import OrderListResponse as OrderListResponse
from .secret_create_params import SecretCreateParams as SecretCreateParams
from .secret_delete_params import SecretDeleteParams as SecretDeleteParams
from .secret_list_response import SecretListResponse as SecretListResponse
from .secret_update_params import SecretUpdateParams as SecretUpdateParams
from .order_retrieve_params import OrderRetrieveParams as OrderRetrieveParams
from .webhook_create_params import WebhookCreateParams as WebhookCreateParams
from .webhook_list_response import WebhookListResponse as WebhookListResponse
from .webhook_update_params import WebhookUpdateParams as WebhookUpdateParams
from .product_order_response import ProductOrderResponse as ProductOrderResponse
from .secret_response_public import SecretResponsePublic as SecretResponsePublic
from .order_retrieve_response import OrderRetrieveResponse as OrderRetrieveResponse
from .shareholder_report_data import ShareholderReportData as ShareholderReportData
from .ultimate_beneficial_owner import UltimateBeneficialOwner as UltimateBeneficialOwner
from .company_extract_ubo_params import CompanyExtractUboParams as CompanyExtractUboParams
from .company_extract_ubo_response import CompanyExtractUboResponse as CompanyExtractUboResponse
from .ultimate_beneficial_owner_report import UltimateBeneficialOwnerReport as UltimateBeneficialOwnerReport
from .company_extract_shareholder_graph_params import (
    CompanyExtractShareholderGraphParams as CompanyExtractShareholderGraphParams,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["SignatoryRules"]


class SignatoryRules(BaseModel):
    english_translation: Optional[str] = FieldInfo(alias="englishTranslation", default=None)

    original: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Any, Optional, cast

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, strip_not_given, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.companies import search_index_params, search_real_time_params, search_autocomplete_params
from ...types.companies.search_index_response import SearchIndexResponse
from ...types.companies.search_real_time_response import SearchRealTimeResponse
from ...types.companies.search_autocomplete_response import SearchAutocompleteResponse

__all__ = ["SearchResource", "AsyncSearchResource"]


class SearchResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> SearchResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/kausate/sdk-python#accessing-raw-response-data-eg-headers
        """
        return SearchResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> SearchResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/kausate/sdk-python#with_streaming_response
        """
        return SearchResourceWithStreamingResponse(self)

    def autocomplete(
        self,
        *,
        query: str,
        jurisdiction_code: Optional[str] | Omit = omit,
        limit: Optional[int] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SearchAutocompleteResponse:
        """
        Get autocomplete suggestions for company names as users type.

        This endpoint provides fast, type-ahead suggestions to help users find companies
        quickly. It's optimized for speed and returns matches based on company names and
        alternative names.

        **Features:**

        - Fast "starts with" matching for responsive UX
        - Searches both primary names and alternative names
        - No credit cost - free to use for better user experience
        - Returns up to 50 results (default: 10)

        **Typical usage:** Use this endpoint to provide autocomplete suggestions in a
        search input field. Once the user selects a company, use the returned
        `kausateId` to:

        - Get full company details
        - Order documents or reports
        - Extract shareholders

        **Parameters:**

        - **jurisdictionCode**: ISO country code (optional, e.g., 'de', 'uk')
        - **query**: Search query (minimum 2 characters)
        - **limit**: Number of results (default: 10, max: 50)

        **Returns:** List of matching companies with kausateId, name, and jurisdiction.

        **Note:** This endpoint does not consume credits.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/v2/companies/search/autocomplete",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "query": query,
                        "jurisdiction_code": jurisdiction_code,
                        "limit": limit,
                    },
                    search_autocomplete_params.SearchAutocompleteParams,
                ),
            ),
            cast_to=SearchAutocompleteResponse,
        )

    def index(
        self,
        *,
        advanced_query: Optional[search_index_params.AdvancedQuery] | Omit = omit,
        include_alternative_names: bool | Omit = omit,
        include_similar_names: bool | Omit = omit,
        jurisdiction_code: str | Omit = omit,
        limit: Optional[int] | Omit = omit,
        name: Optional[str] | Omit = omit,
        page: Optional[int] | Omit = omit,
        x_partner_customer_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SearchIndexResponse:
        """
        Search companies to find the correct company before performing other actions
        (POST method).

        **Note:** This endpoint is free to use - no credit cost.

        **Search Methods:**

        1. **By Name**: Provide `name` field with company name to search
        2. **By Local Identifiers** (Advanced): Provide `advancedQuery` with identifier
           components:
           - **German (DE)**: `courtCity`, `courtId`, `registerType`, `registerNumber`,
             `registerSuffix`
           - **UK**: `companyNumber`

        **Typical workflow:**

        1. Use this endpoint to search for a company by name/identifiers and
           jurisdiction
        2. Select the correct company from the results (using the returned kausateId)
        3. Use the kausateId to:
           - Get company documents
           - Get a company report
           - Extract shareholders

        **Parameters (JSON body):**

        - **jurisdictionCode**: ISO country code (default: "de")
        - **name**: Company name to search (required if advancedQuery not provided)
        - **advancedQuery**: Local identifier components (required if name not provided)
          - For Germany: `courtCity` (e.g., "München"), `courtId` (e.g., "D2803"),
            `registerType` (e.g., "HRB"), `registerNumber` (e.g., "10364B"),
            `registerSuffix` (e.g., "B")
          - For UK: `companyNumber` (e.g., "09410276")
        - **limit**: Max results to return (default: 10, max: 1000)
        - **page**: Page number for pagination (default: 0, 0-based)

        Returns a paginated list of companies, ranked by relevance, with pagination
        metadata.

        Args:
          advanced_query: Jurisdiction-specific advanced search query. The structure varies based on the
              'jurisdiction' field.

          include_alternative_names: If true, searches alternative company names (more expensive). Default: false for
              optimal performance.

          include_similar_names: If true, falls back to trigram similarity search when no exact matches found
              (more expensive). Default: false for optimal performance.

          jurisdiction_code: ISO 3166-1 alpha-2 country code (e.g., 'de' for Germany, 'uk' for United
              Kingdom)

          name: Company name to search for. Either 'name' or 'advancedQuery' must be provided.

          page: Page number (0-based)

          x_partner_customer_id: Optional partner customer ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"X-Partner-Customer-Id": x_partner_customer_id}), **(extra_headers or {})}
        return self._post(
            "/v2/companies/search/indexed",
            body=maybe_transform(
                {
                    "advanced_query": advanced_query,
                    "include_alternative_names": include_alternative_names,
                    "include_similar_names": include_similar_names,
                    "jurisdiction_code": jurisdiction_code,
                    "limit": limit,
                    "name": name,
                    "page": page,
                },
                search_index_params.SearchIndexParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SearchIndexResponse,
        )

    def real_time(
        self,
        *,
        sync: bool | Omit = omit,
        advanced_query: Optional[search_real_time_params.AdvancedQuery] | Omit = omit,
        company_name: Optional[str] | Omit = omit,
        customer_reference: Optional[str] | Omit = omit,
        jurisdiction_code: str | Omit = omit,
        x_partner_customer_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SearchRealTimeResponse:
        """Search for companies in real-time.

        Returns results with generated Kausate IDs.

        Args:
          sync: If True, wait for results. If False, return workflow ID immediately

          advanced_query: Jurisdiction-specific advanced search query. The structure varies based on the
              'jurisdiction' field.

          company_name: Company name to search for. Either 'companyName' or 'advancedQuery' must be
              provided.

          customer_reference: Optional customer reference for tracking

          jurisdiction_code: ISO 3166-1 alpha-2 country code (e.g., 'de' for Germany, 'uk' for United
              Kingdom)

          x_partner_customer_id: Optional partner customer ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"X-Partner-Customer-Id": x_partner_customer_id}), **(extra_headers or {})}
        return cast(
            SearchRealTimeResponse,
            self._post(
                "/v2/companies/search/live",
                body=maybe_transform(
                    {
                        "advanced_query": advanced_query,
                        "company_name": company_name,
                        "customer_reference": customer_reference,
                        "jurisdiction_code": jurisdiction_code,
                    },
                    search_real_time_params.SearchRealTimeParams,
                ),
                options=make_request_options(
                    extra_headers=extra_headers,
                    extra_query=extra_query,
                    extra_body=extra_body,
                    timeout=timeout,
                    query=maybe_transform({"sync": sync}, search_real_time_params.SearchRealTimeParams),
                ),
                cast_to=cast(
                    Any, SearchRealTimeResponse
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )


class AsyncSearchResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncSearchResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/kausate/sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncSearchResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncSearchResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/kausate/sdk-python#with_streaming_response
        """
        return AsyncSearchResourceWithStreamingResponse(self)

    async def autocomplete(
        self,
        *,
        query: str,
        jurisdiction_code: Optional[str] | Omit = omit,
        limit: Optional[int] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SearchAutocompleteResponse:
        """
        Get autocomplete suggestions for company names as users type.

        This endpoint provides fast, type-ahead suggestions to help users find companies
        quickly. It's optimized for speed and returns matches based on company names and
        alternative names.

        **Features:**

        - Fast "starts with" matching for responsive UX
        - Searches both primary names and alternative names
        - No credit cost - free to use for better user experience
        - Returns up to 50 results (default: 10)

        **Typical usage:** Use this endpoint to provide autocomplete suggestions in a
        search input field. Once the user selects a company, use the returned
        `kausateId` to:

        - Get full company details
        - Order documents or reports
        - Extract shareholders

        **Parameters:**

        - **jurisdictionCode**: ISO country code (optional, e.g., 'de', 'uk')
        - **query**: Search query (minimum 2 characters)
        - **limit**: Number of results (default: 10, max: 50)

        **Returns:** List of matching companies with kausateId, name, and jurisdiction.

        **Note:** This endpoint does not consume credits.

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/v2/companies/search/autocomplete",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "query": query,
                        "jurisdiction_code": jurisdiction_code,
                        "limit": limit,
                    },
                    search_autocomplete_params.SearchAutocompleteParams,
                ),
            ),
            cast_to=SearchAutocompleteResponse,
        )

    async def index(
        self,
        *,
        advanced_query: Optional[search_index_params.AdvancedQuery] | Omit = omit,
        include_alternative_names: bool | Omit = omit,
        include_similar_names: bool | Omit = omit,
        jurisdiction_code: str | Omit = omit,
        limit: Optional[int] | Omit = omit,
        name: Optional[str] | Omit = omit,
        page: Optional[int] | Omit = omit,
        x_partner_customer_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SearchIndexResponse:
        """
        Search companies to find the correct company before performing other actions
        (POST method).

        **Note:** This endpoint is free to use - no credit cost.

        **Search Methods:**

        1. **By Name**: Provide `name` field with company name to search
        2. **By Local Identifiers** (Advanced): Provide `advancedQuery` with identifier
           components:
           - **German (DE)**: `courtCity`, `courtId`, `registerType`, `registerNumber`,
             `registerSuffix`
           - **UK**: `companyNumber`

        **Typical workflow:**

        1. Use this endpoint to search for a company by name/identifiers and
           jurisdiction
        2. Select the correct company from the results (using the returned kausateId)
        3. Use the kausateId to:
           - Get company documents
           - Get a company report
           - Extract shareholders

        **Parameters (JSON body):**

        - **jurisdictionCode**: ISO country code (default: "de")
        - **name**: Company name to search (required if advancedQuery not provided)
        - **advancedQuery**: Local identifier components (required if name not provided)
          - For Germany: `courtCity` (e.g., "München"), `courtId` (e.g., "D2803"),
            `registerType` (e.g., "HRB"), `registerNumber` (e.g., "10364B"),
            `registerSuffix` (e.g., "B")
          - For UK: `companyNumber` (e.g., "09410276")
        - **limit**: Max results to return (default: 10, max: 1000)
        - **page**: Page number for pagination (default: 0, 0-based)

        Returns a paginated list of companies, ranked by relevance, with pagination
        metadata.

        Args:
          advanced_query: Jurisdiction-specific advanced search query. The structure varies based on the
              'jurisdiction' field.

          include_alternative_names: If true, searches alternative company names (more expensive). Default: false for
              optimal performance.

          include_similar_names: If true, falls back to trigram similarity search when no exact matches found
              (more expensive). Default: false for optimal performance.

          jurisdiction_code: ISO 3166-1 alpha-2 country code (e.g., 'de' for Germany, 'uk' for United
              Kingdom)

          name: Company name to search for. Either 'name' or 'advancedQuery' must be provided.

          page: Page number (0-based)

          x_partner_customer_id: Optional partner customer ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"X-Partner-Customer-Id": x_partner_customer_id}), **(extra_headers or {})}
        return await self._post(
            "/v2/companies/search/indexed",
            body=await async_maybe_transform(
                {
                    "advanced_query": advanced_query,
                    "include_alternative_names": include_alternative_names,
                    "include_similar_names": include_similar_names,
                    "jurisdiction_code": jurisdiction_code,
                    "limit": limit,
                    "name": name,
                    "page": page,
                },
                search_index_params.SearchIndexParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=SearchIndexResponse,
        )

    async def real_time(
        self,
        *,
        sync: bool | Omit = omit,
        advanced_query: Optional[search_real_time_params.AdvancedQuery] | Omit = omit,
        company_name: Optional[str] | Omit = omit,
        customer_reference: Optional[str] | Omit = omit,
        jurisdiction_code: str | Omit = omit,
        x_partner_customer_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> SearchRealTimeResponse:
        """Search for companies in real-time.

        Returns results with generated Kausate IDs.

        Args:
          sync: If True, wait for results. If False, return workflow ID immediately

          advanced_query: Jurisdiction-specific advanced search query. The structure varies based on the
              'jurisdiction' field.

          company_name: Company name to search for. Either 'companyName' or 'advancedQuery' must be
              provided.

          customer_reference: Optional customer reference for tracking

          jurisdiction_code: ISO 3166-1 alpha-2 country code (e.g., 'de' for Germany, 'uk' for United
              Kingdom)

          x_partner_customer_id: Optional partner customer ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        extra_headers = {**strip_not_given({"X-Partner-Customer-Id": x_partner_customer_id}), **(extra_headers or {})}
        return cast(
            SearchRealTimeResponse,
            await self._post(
                "/v2/companies/search/live",
                body=await async_maybe_transform(
                    {
                        "advanced_query": advanced_query,
                        "company_name": company_name,
                        "customer_reference": customer_reference,
                        "jurisdiction_code": jurisdiction_code,
                    },
                    search_real_time_params.SearchRealTimeParams,
                ),
                options=make_request_options(
                    extra_headers=extra_headers,
                    extra_query=extra_query,
                    extra_body=extra_body,
                    timeout=timeout,
                    query=await async_maybe_transform({"sync": sync}, search_real_time_params.SearchRealTimeParams),
                ),
                cast_to=cast(
                    Any, SearchRealTimeResponse
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )


class SearchResourceWithRawResponse:
    def __init__(self, search: SearchResource) -> None:
        self._search = search

        self.autocomplete = to_raw_response_wrapper(
            search.autocomplete,
        )
        self.index = to_raw_response_wrapper(
            search.index,
        )
        self.real_time = to_raw_response_wrapper(
            search.real_time,
        )


class AsyncSearchResourceWithRawResponse:
    def __init__(self, search: AsyncSearchResource) -> None:
        self._search = search

        self.autocomplete = async_to_raw_response_wrapper(
            search.autocomplete,
        )
        self.index = async_to_raw_response_wrapper(
            search.index,
        )
        self.real_time = async_to_raw_response_wrapper(
            search.real_time,
        )


class SearchResourceWithStreamingResponse:
    def __init__(self, search: SearchResource) -> None:
        self._search = search

        self.autocomplete = to_streamed_response_wrapper(
            search.autocomplete,
        )
        self.index = to_streamed_response_wrapper(
            search.index,
        )
        self.real_time = to_streamed_response_wrapper(
            search.real_time,
        )


class AsyncSearchResourceWithStreamingResponse:
    def __init__(self, search: AsyncSearchResource) -> None:
        self._search = search

        self.autocomplete = async_to_streamed_response_wrapper(
            search.autocomplete,
        )
        self.index = async_to_streamed_response_wrapper(
            search.index,
        )
        self.real_time = async_to_streamed_response_wrapper(
            search.real_time,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["UltimateBeneficialOwnerReport"]


class UltimateBeneficialOwnerReport(BaseModel):
    ultimate_beneficial_owner_report: UltimateBeneficialOwnerReport = FieldInfo(alias="ultimateBeneficialOwnerReport")

    type: Optional[Literal["uboReport"]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Any, Optional, cast

import httpx

from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, strip_not_given, async_maybe_transform
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.companies import document_list_params
from ...types.companies.document_list_response import DocumentListResponse

__all__ = ["DocumentsResource", "AsyncDocumentsResource"]


class DocumentsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> DocumentsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/kausate/sdk-python#accessing-raw-response-data-eg-headers
        """
        return DocumentsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> DocumentsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/kausate/sdk-python#with_streaming_response
        """
        return DocumentsResourceWithStreamingResponse(self)

    def list(
        self,
        kausate_id: str,
        *,
        sync: bool | Omit = omit,
        customer_reference: Optional[str] | Omit = omit,
        x_partner_customer_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DocumentListResponse:
        """
        List all available documents for a company from their business registry.

        **Supported Jurisdictions:**

        - **Germany (DE):** Documents from Unternehmensregister (annual accounts, board
          changes, register announcements, etc.)
        - **Austria (AT):** Documents from Austrian Firmenbuch (Jahresabschluss,
          Lagebericht, Gesellschaftsvertrag, etc.)

        The document list is cached for 24 hours.

        **This endpoint is FREE** - no credits are consumed.

        **Typical workflow:**

        1. Use `GET /v2/companies/search/indexed?name=...&jurisdictionCode=de` to find
           the company
        2. Call this endpoint to get the list of available documents
        3. Use the returned `kausateDocumentId` with
           `POST /v2/companies/{kausateId}/products/order` (pass `kausateDocumentId` in
           the request body) to download a specific document (costs credits)

        **Parameters:**

        - **kausateId**: Company ID (DE or AT jurisdiction)
        - **customerReference**: Optional reference for tracking
        - **sync**: If True (default), wait for results. If False, return workflow ID
          immediately

        **Returns:**

        - If sync=True: List of available documents with their kausateDocumentIds
        - If sync=False: Workflow information for async tracking

        **Note:** Document IDs are cached for 24 hours. After expiration, you'll need to
        call this endpoint again to get fresh document IDs.

        Args:
          kausate_id: Company ID

          sync: Return result synchronously (default: true)

          x_partner_customer_id: Optional partner customer ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not kausate_id:
            raise ValueError(f"Expected a non-empty value for `kausate_id` but received {kausate_id!r}")
        extra_headers = {**strip_not_given({"X-Partner-Customer-Id": x_partner_customer_id}), **(extra_headers or {})}
        return cast(
            DocumentListResponse,
            self._post(
                f"/v2/companies/{kausate_id}/documents/list",
                body=maybe_transform(
                    {"customer_reference": customer_reference}, document_list_params.DocumentListParams
                ),
                options=make_request_options(
                    extra_headers=extra_headers,
                    extra_query=extra_query,
                    extra_body=extra_body,
                    timeout=timeout,
                    query=maybe_transform({"sync": sync}, document_list_params.DocumentListParams),
                ),
                cast_to=cast(
                    Any, DocumentListResponse
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )


class AsyncDocumentsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncDocumentsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/kausate/sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncDocumentsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncDocumentsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/kausate/sdk-python#with_streaming_response
        """
        return AsyncDocumentsResourceWithStreamingResponse(self)

    async def list(
        self,
        kausate_id: str,
        *,
        sync: bool | Omit = omit,
        customer_reference: Optional[str] | Omit = omit,
        x_partner_customer_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> DocumentListResponse:
        """
        List all available documents for a company from their business registry.

        **Supported Jurisdictions:**

        - **Germany (DE):** Documents from Unternehmensregister (annual accounts, board
          changes, register announcements, etc.)
        - **Austria (AT):** Documents from Austrian Firmenbuch (Jahresabschluss,
          Lagebericht, Gesellschaftsvertrag, etc.)

        The document list is cached for 24 hours.

        **This endpoint is FREE** - no credits are consumed.

        **Typical workflow:**

        1. Use `GET /v2/companies/search/indexed?name=...&jurisdictionCode=de` to find
           the company
        2. Call this endpoint to get the list of available documents
        3. Use the returned `kausateDocumentId` with
           `POST /v2/companies/{kausateId}/products/order` (pass `kausateDocumentId` in
           the request body) to download a specific document (costs credits)

        **Parameters:**

        - **kausateId**: Company ID (DE or AT jurisdiction)
        - **customerReference**: Optional reference for tracking
        - **sync**: If True (default), wait for results. If False, return workflow ID
          immediately

        **Returns:**

        - If sync=True: List of available documents with their kausateDocumentIds
        - If sync=False: Workflow information for async tracking

        **Note:** Document IDs are cached for 24 hours. After expiration, you'll need to
        call this endpoint again to get fresh document IDs.

        Args:
          kausate_id: Company ID

          sync: Return result synchronously (default: true)

          x_partner_customer_id: Optional partner customer ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not kausate_id:
            raise ValueError(f"Expected a non-empty value for `kausate_id` but received {kausate_id!r}")
        extra_headers = {**strip_not_given({"X-Partner-Customer-Id": x_partner_customer_id}), **(extra_headers or {})}
        return cast(
            DocumentListResponse,
            await self._post(
                f"/v2/companies/{kausate_id}/documents/list",
                body=await async_maybe_transform(
                    {"customer_reference": customer_reference}, document_list_params.DocumentListParams
                ),
                options=make_request_options(
                    extra_headers=extra_headers,
                    extra_query=extra_query,
                    extra_body=extra_body,
                    timeout=timeout,
                    query=await async_maybe_transform({"sync": sync}, document_list_params.DocumentListParams),
                ),
                cast_to=cast(
                    Any, DocumentListResponse
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )


class DocumentsResourceWithRawResponse:
    def __init__(self, documents: DocumentsResource) -> None:
        self._documents = documents

        self.list = to_raw_response_wrapper(
            documents.list,
        )


class AsyncDocumentsResourceWithRawResponse:
    def __init__(self, documents: AsyncDocumentsResource) -> None:
        self._documents = documents

        self.list = async_to_raw_response_wrapper(
            documents.list,
        )


class DocumentsResourceWithStreamingResponse:
    def __init__(self, documents: DocumentsResource) -> None:
        self._documents = documents

        self.list = to_streamed_response_wrapper(
            documents.list,
        )


class AsyncDocumentsResourceWithStreamingResponse:
    def __init__(self, documents: AsyncDocumentsResource) -> None:
        self._documents = documents

        self.list = async_to_streamed_response_wrapper(
            documents.list,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["SecretListParams"]


class SecretListParams(TypedDict, total=False):
    datasource_slug: Annotated[Optional[str], PropertyInfo(alias="datasourceSlug")]
    """Filter by datasource slug"""

    partner_customer_id: Annotated[Optional[str], PropertyInfo(alias="partnerCustomerId")]
    """Partner customer ID"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .webhook_response import WebhookResponse

__all__ = ["WebhookListResponse"]

WebhookListResponse: TypeAlias = List[WebhookResponse]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["OrderRetrieveParams"]


class OrderRetrieveParams(TypedDict, total=False):
    customer_partner_id: Annotated[Optional[str], PropertyInfo(alias="customerPartnerId")]
    """Optional customer partner ID for validation"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .role import Role
from .person import Person
from .status import Status
from .._models import BaseModel
from .currency import Currency
from .legal_form import LegalForm
from .interest_type import InterestType
from .percentage_share import PercentageShare
from .companies.address import Address
from .companies.identifier import Identifier

__all__ = ["Shareholder", "Company"]


class Company(BaseModel):
    address: Optional[Address] = None
    """Address of a company or person."""

    identifiers: Optional[List[Identifier]] = None

    jurisdiction_code: Optional[str] = FieldInfo(alias="jurisdictionCode", default=None)
    """ISO 3166-1 alpha-2 country/jurisdiction code"""

    legal_form: Optional[LegalForm] = FieldInfo(alias="legalForm", default=None)

    name: Optional[str] = None

    status: Optional[Status] = None


class Shareholder(BaseModel):
    type: Literal["person", "company", "freeFloat"]
    """Type of shareholder"""

    company: Optional[Company] = None
    """A legal entity or organization"""

    description: Optional[str] = None

    interest_details: Optional[str] = FieldInfo(alias="interestDetails", default=None)
    """
    Additional details about the interest, such as the specific role name (e.g.,
    'Komplementär')
    """

    interest_type: Optional[InterestType] = FieldInfo(alias="interestType", default=None)
    """
    Describes the nature of the interest or control that an entity or person has in
    another entity.
    """

    number_of_shares: Optional[int] = FieldInfo(alias="numberOfShares", default=None)

    percentage: Optional[PercentageShare] = None
    """
    The proportion of this type of interest held by the interested party, where an
    interest is countable.
    """

    person: Optional[Person] = None
    """A natural person (human being)"""

    role: Optional[Role] = None

    share_class: Optional[str] = FieldInfo(alias="shareClass", default=None)

    source: Optional[str] = None

    total_nominal_value: Optional[Currency] = FieldInfo(alias="totalNominalValue", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["CompanyReport"]


class CompanyReport(BaseModel):
    company_report: CompanyReport = FieldInfo(alias="companyReport")

    type: Optional[Literal["companyReport"]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from datetime import datetime

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["OrderListResponse", "Order"]


class Order(BaseModel):
    order_id: str = FieldInfo(alias="orderId")

    request_time: datetime = FieldInfo(alias="requestTime")
    """Time when the order was created"""

    status: str
    """Order status"""

    company_name: Optional[str] = FieldInfo(alias="companyName", default=None)
    """Company name from search attributes"""

    customer_reference: Optional[str] = FieldInfo(alias="customerReference", default=None)

    partner_customer_id: Optional[str] = FieldInfo(alias="partnerCustomerId", default=None)

    response_time: Optional[datetime] = FieldInfo(alias="responseTime", default=None)
    """Time when the order completed"""


class OrderListResponse(BaseModel):
    orders: List[Order]
    """List of orders"""

    total: int
    """Total number of orders returned"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Union
from typing_extensions import TypeAlias

from ..company_report import CompanyReport
from ..product_order_response import ProductOrderResponse

__all__ = ["ReportCreateResponse"]

ReportCreateResponse: TypeAlias = Union[ProductOrderResponse, CompanyReport]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Any, Optional, cast

import httpx

from .report import (
    ReportResource,
    AsyncReportResource,
    ReportResourceWithRawResponse,
    AsyncReportResourceWithRawResponse,
    ReportResourceWithStreamingResponse,
    AsyncReportResourceWithStreamingResponse,
)
from .search import (
    SearchResource,
    AsyncSearchResource,
    SearchResourceWithRawResponse,
    AsyncSearchResourceWithRawResponse,
    SearchResourceWithStreamingResponse,
    AsyncSearchResourceWithStreamingResponse,
)
from ...types import company_extract_ubo_params, company_extract_shareholder_graph_params
from ..._types import Body, Omit, Query, Headers, NotGiven, omit, not_given
from ..._utils import maybe_transform, strip_not_given, async_maybe_transform
from .products import (
    ProductsResource,
    AsyncProductsResource,
    ProductsResourceWithRawResponse,
    AsyncProductsResourceWithRawResponse,
    ProductsResourceWithStreamingResponse,
    AsyncProductsResourceWithStreamingResponse,
)
from ..._compat import cached_property
from .documents import (
    DocumentsResource,
    AsyncDocumentsResource,
    DocumentsResourceWithRawResponse,
    AsyncDocumentsResourceWithRawResponse,
    DocumentsResourceWithStreamingResponse,
    AsyncDocumentsResourceWithStreamingResponse,
)
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.product_order_response import ProductOrderResponse
from ...types.company_extract_ubo_response import CompanyExtractUboResponse

__all__ = ["CompaniesResource", "AsyncCompaniesResource"]


class CompaniesResource(SyncAPIResource):
    @cached_property
    def search(self) -> SearchResource:
        return SearchResource(self._client)

    @cached_property
    def products(self) -> ProductsResource:
        return ProductsResource(self._client)

    @cached_property
    def report(self) -> ReportResource:
        return ReportResource(self._client)

    @cached_property
    def documents(self) -> DocumentsResource:
        return DocumentsResource(self._client)

    @cached_property
    def with_raw_response(self) -> CompaniesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/kausate/sdk-python#accessing-raw-response-data-eg-headers
        """
        return CompaniesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> CompaniesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/kausate/sdk-python#with_streaming_response
        """
        return CompaniesResourceWithStreamingResponse(self)

    def extract_shareholder_graph(
        self,
        kausate_id: str,
        *,
        customer_reference: Optional[str] | Omit = omit,
        max_depth: int | Omit = omit,
        x_partner_customer_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ProductOrderResponse:
        """
        Extract multi-level shareholder graph showing shareholders and their
        shareholders.

        This endpoint builds a complete shareholder graph by recursively extracting
        shareholders at multiple levels.

        **Key Features:**

        - Extracts shareholders up to the specified depth (max 5 levels)
        - Returns a graph of nodes and edges

        **Typical workflow:**

        1. Use `GET /v2/companies/search/indexed?name=...&jurisdictionCode=...` to find
           the company
        2. Call this endpoint `POST /v2/companies/{kausateId}/shareholder-graph` with
           depth settings
        3. Poll `GET /v2/orders/{orderId}` for the complete graph result

        **Parameters:**

        - **kausateId**: Root company ID to start extraction from
        - **maxDepth**: Maximum levels to extract (1-5, default: 3)
        - **customerReference**: Optional reference for tracking

        **Returns:** Order ID for tracking the extraction (poll for results)

        **Note:** This is a compute-intensive operation and highly depends on the
        availability of underlying data sources.

        Args:
          kausate_id: Company ID

          max_depth: Maximum depth of ownership levels to extract (1-7)

          x_partner_customer_id: Optional partner customer ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not kausate_id:
            raise ValueError(f"Expected a non-empty value for `kausate_id` but received {kausate_id!r}")
        extra_headers = {**strip_not_given({"X-Partner-Customer-Id": x_partner_customer_id}), **(extra_headers or {})}
        return self._post(
            f"/v2/companies/{kausate_id}/shareholder-graph",
            body=maybe_transform(
                {
                    "customer_reference": customer_reference,
                    "max_depth": max_depth,
                },
                company_extract_shareholder_graph_params.CompanyExtractShareholderGraphParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ProductOrderResponse,
        )

    def extract_ubo(
        self,
        kausate_id: str,
        *,
        sync: bool | Omit = omit,
        customer_reference: Optional[str] | Omit = omit,
        x_partner_customer_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CompanyExtractUboResponse:
        """
        Retrieve UBOs from beneficial ownership registers (asynchronous or synchronous
        processing).

        This operation retrieves UBO information from official beneficial ownership
        registers.

        Typical workflow:

        1. Use `GET /v2/companies/search/indexed?name=...&jurisdictionCode=...` to find
           the company and get its `kausateId`.
        2. Call this endpoint `POST /v2/companies/{kausateId}/ubo` with the required
           request body.
        3. If sync=false (default): Use the returned `orderId` to poll
           `GET /v2/orders/{orderId}` for the extraction result.
        4. If sync=true: The response will contain the UBO data directly (300s timeout).

        - **kausateId**: Company ID to extract UBOs for
        - **customerReference**: Optional reference for tracking
        - **sync**: Return result synchronously with 300s timeout (default: false)

        Returns order ID for tracking (async) or UBO data (sync).

        Note: This endpoint costs 10 credits per request.

        Args:
          kausate_id: Company ID

          sync: Return result synchronously with 300s timeout

          x_partner_customer_id: Optional partner customer ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not kausate_id:
            raise ValueError(f"Expected a non-empty value for `kausate_id` but received {kausate_id!r}")
        extra_headers = {**strip_not_given({"X-Partner-Customer-Id": x_partner_customer_id}), **(extra_headers or {})}
        return cast(
            CompanyExtractUboResponse,
            self._post(
                f"/v2/companies/{kausate_id}/ubo",
                body=maybe_transform(
                    {"customer_reference": customer_reference}, company_extract_ubo_params.CompanyExtractUboParams
                ),
                options=make_request_options(
                    extra_headers=extra_headers,
                    extra_query=extra_query,
                    extra_body=extra_body,
                    timeout=timeout,
                    query=maybe_transform({"sync": sync}, company_extract_ubo_params.CompanyExtractUboParams),
                ),
                cast_to=cast(
                    Any, CompanyExtractUboResponse
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )


class AsyncCompaniesResource(AsyncAPIResource):
    @cached_property
    def search(self) -> AsyncSearchResource:
        return AsyncSearchResource(self._client)

    @cached_property
    def products(self) -> AsyncProductsResource:
        return AsyncProductsResource(self._client)

    @cached_property
    def report(self) -> AsyncReportResource:
        return AsyncReportResource(self._client)

    @cached_property
    def documents(self) -> AsyncDocumentsResource:
        return AsyncDocumentsResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncCompaniesResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/kausate/sdk-python#accessing-raw-response-data-eg-headers
        """
        return AsyncCompaniesResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncCompaniesResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/kausate/sdk-python#with_streaming_response
        """
        return AsyncCompaniesResourceWithStreamingResponse(self)

    async def extract_shareholder_graph(
        self,
        kausate_id: str,
        *,
        customer_reference: Optional[str] | Omit = omit,
        max_depth: int | Omit = omit,
        x_partner_customer_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> ProductOrderResponse:
        """
        Extract multi-level shareholder graph showing shareholders and their
        shareholders.

        This endpoint builds a complete shareholder graph by recursively extracting
        shareholders at multiple levels.

        **Key Features:**

        - Extracts shareholders up to the specified depth (max 5 levels)
        - Returns a graph of nodes and edges

        **Typical workflow:**

        1. Use `GET /v2/companies/search/indexed?name=...&jurisdictionCode=...` to find
           the company
        2. Call this endpoint `POST /v2/companies/{kausateId}/shareholder-graph` with
           depth settings
        3. Poll `GET /v2/orders/{orderId}` for the complete graph result

        **Parameters:**

        - **kausateId**: Root company ID to start extraction from
        - **maxDepth**: Maximum levels to extract (1-5, default: 3)
        - **customerReference**: Optional reference for tracking

        **Returns:** Order ID for tracking the extraction (poll for results)

        **Note:** This is a compute-intensive operation and highly depends on the
        availability of underlying data sources.

        Args:
          kausate_id: Company ID

          max_depth: Maximum depth of ownership levels to extract (1-7)

          x_partner_customer_id: Optional partner customer ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not kausate_id:
            raise ValueError(f"Expected a non-empty value for `kausate_id` but received {kausate_id!r}")
        extra_headers = {**strip_not_given({"X-Partner-Customer-Id": x_partner_customer_id}), **(extra_headers or {})}
        return await self._post(
            f"/v2/companies/{kausate_id}/shareholder-graph",
            body=await async_maybe_transform(
                {
                    "customer_reference": customer_reference,
                    "max_depth": max_depth,
                },
                company_extract_shareholder_graph_params.CompanyExtractShareholderGraphParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=ProductOrderResponse,
        )

    async def extract_ubo(
        self,
        kausate_id: str,
        *,
        sync: bool | Omit = omit,
        customer_reference: Optional[str] | Omit = omit,
        x_partner_customer_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> CompanyExtractUboResponse:
        """
        Retrieve UBOs from beneficial ownership registers (asynchronous or synchronous
        processing).

        This operation retrieves UBO information from official beneficial ownership
        registers.

        Typical workflow:

        1. Use `GET /v2/companies/search/indexed?name=...&jurisdictionCode=...` to find
           the company and get its `kausateId`.
        2. Call this endpoint `POST /v2/companies/{kausateId}/ubo` with the required
           request body.
        3. If sync=false (default): Use the returned `orderId` to poll
           `GET /v2/orders/{orderId}` for the extraction result.
        4. If sync=true: The response will contain the UBO data directly (300s timeout).

        - **kausateId**: Company ID to extract UBOs for
        - **customerReference**: Optional reference for tracking
        - **sync**: Return result synchronously with 300s timeout (default: false)

        Returns order ID for tracking (async) or UBO data (sync).

        Note: This endpoint costs 10 credits per request.

        Args:
          kausate_id: Company ID

          sync: Return result synchronously with 300s timeout

          x_partner_customer_id: Optional partner customer ID

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not kausate_id:
            raise ValueError(f"Expected a non-empty value for `kausate_id` but received {kausate_id!r}")
        extra_headers = {**strip_not_given({"X-Partner-Customer-Id": x_partner_customer_id}), **(extra_headers or {})}
        return cast(
            CompanyExtractUboResponse,
            await self._post(
                f"/v2/companies/{kausate_id}/ubo",
                body=await async_maybe_transform(
                    {"customer_reference": customer_reference}, company_extract_ubo_params.CompanyExtractUboParams
                ),
                options=make_request_options(
                    extra_headers=extra_headers,
                    extra_query=extra_query,
                    extra_body=extra_body,
                    timeout=timeout,
                    query=await async_maybe_transform(
                        {"sync": sync}, company_extract_ubo_params.CompanyExtractUboParams
                    ),
                ),
                cast_to=cast(
                    Any, CompanyExtractUboResponse
                ),  # Union types cannot be passed in as arguments in the type system
            ),
        )


class CompaniesResourceWithRawResponse:
    def __init__(self, companies: CompaniesResource) -> None:
        self._companies = companies

        self.extract_shareholder_graph = to_raw_response_wrapper(
            companies.extract_shareholder_graph,
        )
        self.extract_ubo = to_raw_response_wrapper(
            companies.extract_ubo,
        )

    @cached_property
    def search(self) -> SearchResourceWithRawResponse:
        return SearchResourceWithRawResponse(self._companies.search)

    @cached_property
    def products(self) -> ProductsResourceWithRawResponse:
        return ProductsResourceWithRawResponse(self._companies.products)

    @cached_property
    def report(self) -> ReportResourceWithRawResponse:
        return ReportResourceWithRawResponse(self._companies.report)

    @cached_property
    def documents(self) -> DocumentsResourceWithRawResponse:
        return DocumentsResourceWithRawResponse(self._companies.documents)


class AsyncCompaniesResourceWithRawResponse:
    def __init__(self, companies: AsyncCompaniesResource) -> None:
        self._companies = companies

        self.extract_shareholder_graph = async_to_raw_response_wrapper(
            companies.extract_shareholder_graph,
        )
        self.extract_ubo = async_to_raw_response_wrapper(
            companies.extract_ubo,
        )

    @cached_property
    def search(self) -> AsyncSearchResourceWithRawResponse:
        return AsyncSearchResourceWithRawResponse(self._companies.search)

    @cached_property
    def products(self) -> AsyncProductsResourceWithRawResponse:
        return AsyncProductsResourceWithRawResponse(self._companies.products)

    @cached_property
    def report(self) -> AsyncReportResourceWithRawResponse:
        return AsyncReportResourceWithRawResponse(self._companies.report)

    @cached_property
    def documents(self) -> AsyncDocumentsResourceWithRawResponse:
        return AsyncDocumentsResourceWithRawResponse(self._companies.documents)


class CompaniesResourceWithStreamingResponse:
    def __init__(self, companies: CompaniesResource) -> None:
        self._companies = companies

        self.extract_shareholder_graph = to_streamed_response_wrapper(
            companies.extract_shareholder_graph,
        )
        self.extract_ubo = to_streamed_response_wrapper(
            companies.extract_ubo,
        )

    @cached_property
    def search(self) -> SearchResourceWithStreamingResponse:
        return SearchResourceWithStreamingResponse(self._companies.search)

    @cached_property
    def products(self) -> ProductsResourceWithStreamingResponse:
        return ProductsResourceWithStreamingResponse(self._companies.products)

    @cached_property
    def report(self) -> ReportResourceWithStreamingResponse:
        return ReportResourceWithStreamingResponse(self._companies.report)

    @cached_property
    def documents(self) -> DocumentsResourceWithStreamingResponse:
        return DocumentsResourceWithStreamingResponse(self._companies.documents)


class AsyncCompaniesResourceWithStreamingResponse:
    def __init__(self, companies: AsyncCompaniesResource) -> None:
        self._companies = companies

        self.extract_shareholder_graph = async_to_streamed_response_wrapper(
            companies.extract_shareholder_graph,
        )
        self.extract_ubo = async_to_streamed_response_wrapper(
            companies.extract_ubo,
        )

    @cached_property
    def search(self) -> AsyncSearchResourceWithStreamingResponse:
        return AsyncSearchResourceWithStreamingResponse(self._companies.search)

    @cached_property
    def products(self) -> AsyncProductsResourceWithStreamingResponse:
        return AsyncProductsResourceWithStreamingResponse(self._companies.products)

    @cached_property
    def report(self) -> AsyncReportResourceWithStreamingResponse:
        return AsyncReportResourceWithStreamingResponse(self._companies.report)

    @cached_property
    def documents(self) -> AsyncDocumentsResourceWithStreamingResponse:
        return AsyncDocumentsResourceWithStreamingResponse(self._companies.documents)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from datetime import datetime

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["SecretResponsePublic"]


class SecretResponsePublic(BaseModel):
    created_at: datetime = FieldInfo(alias="createdAt")

    datasource_name: str = FieldInfo(alias="datasourceName")

    datasource_slug: str = FieldInfo(alias="datasourceSlug")

    updated_at: datetime = FieldInfo(alias="updatedAt")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["Currency"]


class Currency(BaseModel):
    amount: Optional[str] = None

    iso4217_currency_code: Optional[str] = FieldInfo(alias="iso4217CurrencyCode", default=None)
    """Currency code in ISO 4217 format"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["Status"]


class Status(BaseModel):
    is_active: Optional[bool] = FieldInfo(alias="isActive", default=None)

    normalized: Optional[
        Literal[
            "active",
            "closed",
            "closing",
            "dissolved",
            "expanded",
            "expired",
            "inReceivership",
            "inactive",
            "incorporated",
            "opening",
            "registered",
            "registrationRevoked",
            "seized",
            "terminated",
            "underExternalControl",
        ]
    ] = None
    """Company status type definitions with descriptions"""

    original: Optional[str] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["OrderListParams"]


class OrderListParams(TypedDict, total=False):
    limit: int
    """Maximum number of orders to return"""

    workflow_type: Annotated[
        Optional[Literal["DocumentRetrieval", "CompanyReport", "ShareholderGraph", "UBOExtraction"]],
        PropertyInfo(alias="workflowType"),
    ]
    """Available workflow types for filtering orders."""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Dict, Optional
from typing_extensions import Required, TypedDict

from .webhook_status import WebhookStatus

__all__ = ["WebhookCreateParams"]


class WebhookCreateParams(TypedDict, total=False):
    name: Required[str]
    """Name of the webhook"""

    url: Required[str]
    """URL to receive webhook notifications"""

    api_version: str
    """API version for the webhook"""

    custom_headers: Optional[Dict[str, str]]
    """Custom request headers to include in webhook requests"""

    description: Optional[str]
    """Optional description"""

    partner_customer_id: Optional[str]
    """Optional partner customer ID"""

    status: WebhookStatus
    """Webhook status"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from datetime import datetime
from typing_extensions import TypeAlias

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["SecretListResponse", "SecretListResponseItem"]


class SecretListResponseItem(BaseModel):
    created_at: datetime = FieldInfo(alias="createdAt")

    datasource_name: str = FieldInfo(alias="datasourceName")

    datasource_slug: str = FieldInfo(alias="datasourceSlug")

    updated_at: datetime = FieldInfo(alias="updatedAt")


SecretListResponse: TypeAlias = List[SecretListResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Union
from typing_extensions import TypeAlias

from .product_order_response import ProductOrderResponse
from .ultimate_beneficial_owner_report import UltimateBeneficialOwnerReport

__all__ = ["CompanyExtractUboResponse"]

CompanyExtractUboResponse: TypeAlias = Union[ProductOrderResponse, UltimateBeneficialOwnerReport]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["Address", "Normalized"]


class Normalized(BaseModel):
    category: Optional[str] = None

    city: Optional[str] = None

    city_district: Optional[str] = FieldInfo(alias="cityDistrict", default=None)

    country: Optional[str] = None

    country_code: Optional[str] = FieldInfo(alias="countryCode", default=None)

    country_region: Optional[str] = FieldInfo(alias="countryRegion", default=None)

    county: Optional[str] = None

    entrance: Optional[str] = None

    house: Optional[str] = None

    house_number: Optional[str] = FieldInfo(alias="houseNumber", default=None)

    island: Optional[str] = None

    level: Optional[str] = None

    near: Optional[str] = None

    po_box: Optional[str] = FieldInfo(alias="poBox", default=None)

    postcode: Optional[str] = None

    road: Optional[str] = None

    staircase: Optional[str] = None

    state: Optional[str] = None

    state_district: Optional[str] = FieldInfo(alias="stateDistrict", default=None)

    suburb: Optional[str] = None

    unit: Optional[str] = None

    world_region: Optional[str] = FieldInfo(alias="worldRegion", default=None)


class Address(BaseModel):
    normalized: Optional[Normalized] = None
    """Normalized address fields with null values excluded from serialization."""

    original: Optional[str] = None

    source: Optional[str] = None

    type: Optional[
        Literal[
            "arrival",
            "business",
            "departure",
            "mailing",
            "operations",
            "physical",
            "placeOfBirth",
            "receiverAddress",
            "registered",
            "residential",
            "shipperAddress",
            "transit",
        ]
    ] = None
    """Address type definitions with descriptions"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from kausate import Kausate, AsyncKausate
from tests.utils import assert_matches_type
from kausate.types.companies import ProductOrderResponse

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestProducts:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_order(self, client: Kausate) -> None:
        product = client.companies.products.order(
            kausate_id="kausateId",
        )
        assert_matches_type(ProductOrderResponse, product, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_method_order_with_all_params(self, client: Kausate) -> None:
        product = client.companies.products.order(
            kausate_id="kausateId",
            sync=True,
            customer_reference="customerReference",
            kausate_document_id="kausateDocumentId",
            output_format="pdf",
            sku="sku",
            x_partner_customer_id="X-Partner-Customer-Id",
        )
        assert_matches_type(ProductOrderResponse, product, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_raw_response_order(self, client: Kausate) -> None:
        response = client.companies.products.with_raw_response.order(
            kausate_id="kausateId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        product = response.parse()
        assert_matches_type(ProductOrderResponse, product, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_streaming_response_order(self, client: Kausate) -> None:
        with client.companies.products.with_streaming_response.order(
            kausate_id="kausateId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            product = response.parse()
            assert_matches_type(ProductOrderResponse, product, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    def test_path_params_order(self, client: Kausate) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `kausate_id` but received ''"):
            client.companies.products.with_raw_response.order(
                kausate_id="",
            )


class TestAsyncProducts:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_order(self, async_client: AsyncKausate) -> None:
        product = await async_client.companies.products.order(
            kausate_id="kausateId",
        )
        assert_matches_type(ProductOrderResponse, product, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_method_order_with_all_params(self, async_client: AsyncKausate) -> None:
        product = await async_client.companies.products.order(
            kausate_id="kausateId",
            sync=True,
            customer_reference="customerReference",
            kausate_document_id="kausateDocumentId",
            output_format="pdf",
            sku="sku",
            x_partner_customer_id="X-Partner-Customer-Id",
        )
        assert_matches_type(ProductOrderResponse, product, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_raw_response_order(self, async_client: AsyncKausate) -> None:
        response = await async_client.companies.products.with_raw_response.order(
            kausate_id="kausateId",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        product = await response.parse()
        assert_matches_type(ProductOrderResponse, product, path=["response"])

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_streaming_response_order(self, async_client: AsyncKausate) -> None:
        async with async_client.companies.products.with_streaming_response.order(
            kausate_id="kausateId",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            product = await response.parse()
            assert_matches_type(ProductOrderResponse, product, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Prism tests are disabled")
    @parametrize
    async def test_path_params_order(self, async_client: AsyncKausate) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `kausate_id` but received ''"):
            await async_client.companies.products.with_raw_response.order(
                kausate_id="",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .report import (
    ReportResource,
    AsyncReportResource,
    ReportResourceWithRawResponse,
    AsyncReportResourceWithRawResponse,
    ReportResourceWithStreamingResponse,
    AsyncReportResourceWithStreamingResponse,
)
from .search import (
    SearchResource,
    AsyncSearchResource,
    SearchResourceWithRawResponse,
    AsyncSearchResourceWithRawResponse,
    SearchResourceWithStreamingResponse,
    AsyncSearchResourceWithStreamingResponse,
)
from .products import (
    ProductsResource,
    AsyncProductsResource,
    ProductsResourceWithRawResponse,
    AsyncProductsResourceWithRawResponse,
    ProductsResourceWithStreamingResponse,
    AsyncProductsResourceWithStreamingResponse,
)
from .companies import (
    CompaniesResource,
    AsyncCompaniesResource,
    CompaniesResourceWithRawResponse,
    AsyncCompaniesResourceWithRawResponse,
    CompaniesResourceWithStreamingResponse,
    AsyncCompaniesResourceWithStreamingResponse,
)
from .documents import (
    DocumentsResource,
    AsyncDocumentsResource,
    DocumentsResourceWithRawResponse,
    AsyncDocumentsResourceWithRawResponse,
    DocumentsResourceWithStreamingResponse,
    AsyncDocumentsResourceWithStreamingResponse,
)

__all__ = [
    "SearchResource",
    "AsyncSearchResource",
    "SearchResourceWithRawResponse",
    "AsyncSearchResourceWithRawResponse",
    "SearchResourceWithStreamingResponse",
    "AsyncSearchResourceWithStreamingResponse",
    "ProductsResource",
    "AsyncProductsResource",
    "ProductsResourceWithRawResponse",
    "AsyncProductsResourceWithRawResponse",
    "ProductsResourceWithStreamingResponse",
    "AsyncProductsResourceWithStreamingResponse",
    "ReportResource",
    "AsyncReportResource",
    "ReportResourceWithRawResponse",
    "AsyncReportResourceWithRawResponse",
    "ReportResourceWithStreamingResponse",
    "AsyncReportResourceWithStreamingResponse",
    "DocumentsResource",
    "AsyncDocumentsResource",
    "DocumentsResourceWithRawResponse",
    "AsyncDocumentsResourceWithRawResponse",
    "DocumentsResourceWithStreamingResponse",
    "AsyncDocumentsResourceWithStreamingResponse",
    "CompaniesResource",
    "AsyncCompaniesResource",
    "CompaniesResourceWithRawResponse",
    "AsyncCompaniesResourceWithRawResponse",
    "CompaniesResourceWithStreamingResponse",
    "AsyncCompaniesResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["SearchAutocompleteParams"]


class SearchAutocompleteParams(TypedDict, total=False):
    query: Required[str]

    jurisdiction_code: Annotated[Optional[str], PropertyInfo(alias="jurisdictionCode")]

    limit: Optional[int]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .date_info import DateInfo
from .shareholder import Shareholder

__all__ = ["ShareholderReportData", "Sources"]


class Sources(BaseModel):
    type: Literal["selfDeclaration", "officialRegister", "thirdParty", "primaryResearch", "verified"]
    """Source type for information origin."""

    date: Optional[DateInfo] = None

    download_url: Optional[str] = FieldInfo(alias="downloadUrl", default=None)

    file_hash: Optional[str] = FieldInfo(alias="fileHash", default=None)

    file_name: Optional[str] = FieldInfo(alias="fileName", default=None)

    jurisdiction_code: Optional[str] = FieldInfo(alias="jurisdictionCode", default=None)

    name: Optional[str] = None

    retrieval_time: Optional[str] = FieldInfo(alias="retrievalTime", default=None)


class ShareholderReportData(BaseModel):
    shareholders: Optional[List[Shareholder]] = None

    sources: Optional[Dict[str, Sources]] = None



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from ..._models import BaseModel
from .identifier import Identifier

__all__ = ["SearchAutocompleteResponse", "Result"]


class Result(BaseModel):
    jurisdiction_code: str = FieldInfo(alias="jurisdictionCode")
    """ISO 3166-1 alpha-2 country code"""

    kausate_id: str = FieldInfo(alias="kausateId")

    name: str

    alternative_names: Optional[str] = FieldInfo(alias="alternativeNames", default=None)
    """Alternative name that matched the search query, if applicable"""

    identifiers: Optional[List[Identifier]] = None
    """List of identifiers for autocomplete display (register numbers, IDs, etc.)"""


class SearchAutocompleteResponse(BaseModel):
    results: List[Result]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["ProductOrderResponse"]


class ProductOrderResponse(BaseModel):
    order_id: str = FieldInfo(alias="orderId")

    customer_reference: Optional[str] = FieldInfo(alias="customerReference", default=None)

    partner_customer_id: Optional[str] = FieldInfo(alias="partnerCustomerId", default=None)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Dict, List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .date_info import DateInfo
from .companies.address import Address
from .companies.identifier import Identifier

__all__ = ["Person", "Name"]


class Name(BaseModel):
    first_name: Optional[str] = FieldInfo(alias="firstName", default=None)

    full_name: Optional[str] = FieldInfo(alias="fullName", default=None)

    last_name: Optional[str] = FieldInfo(alias="lastName", default=None)


class Person(BaseModel):
    address: Optional[Address] = None
    """Address of a company or person."""

    contact: Optional[Dict[str, str]] = None

    date_of_birth: Optional[DateInfo] = FieldInfo(alias="dateOfBirth", default=None)

    gender: Optional[str] = None

    identifiers: Optional[List[Identifier]] = None

    jurisdiction_code: Optional[str] = FieldInfo(alias="jurisdictionCode", default=None)
    """ISO 3166-1 alpha-2 country/jurisdiction code"""

    name: Optional[Name] = None

    nationality: Optional[str] = None
